@@ -43,6 +43,7 @@ class MetaData:
         tz_offset_sec: int or None if not set, offset from UTC in seconds
         height: int or None if not set, height of photo in pixels
         width: int or None if not set, width of photo in pixels
+        tzname: str or None if not set, timezone name for timezone
     """
 
     title: str = ""
@@ -57,16 +58,14 @@ class MetaData:
     tz_offset_sec: float | None = None
     height: int | None = None
     width: int | None = None
+    tzname: str | None = None
 
     def __ior__(self, other):
-        if isinstance(other, MetaData):
-            for field in fields(self):
-                other_value = getattr(other, field.name)
-                self_value = getattr(self, field.name)
-                if other_value:
-                    setattr(self, field.name, other_value)
-        else:
+        if not isinstance(other, MetaData):
             raise TypeError("Unsupported operand type")
+        for f in fields(self):
+            if other_value := getattr(other, f.name):
+                setattr(self, f.name, other_value)
         return self
 
 
@@ -131,7 +130,7 @@ def get_sidecar_for_file(filepath: str | pathlib.Path) -> pathlib.Path | None:
         Tests for both JSON and XMP sidecar. If both exists, JSON is returned.
         Tests both with and without original suffix. If both exists, file with original suffix is returned.
         E.g. search order is: img_1234.jpg.json, img_1234.json, img_1234.jpg.xmp, img_1234.xmp
-        For Google Takeout, the sidecar may be named img_1234.jpg.json or img_1234.json;
+        For Google Takeout, the sidecar may be named img_1234.jpg.json, img_1234.json, or img_1234.jpg.supplemental-metadata.json;
         if the image is edited, it will be named img_1234-edited.jpg but the sidecar will still be
         named img_1234.jpg.json or img_1234.json so drop the -edited suffix when searching for the sidecar.
         If there is a duplicate file name, Google Takeout will append a number to the file name
@@ -148,6 +147,11 @@ def get_sidecar_for_file(filepath: str | pathlib.Path) -> pathlib.Path | None:
         if sidecar.is_file():
             return sidecar
 
+    # check for Google Takeout supplemental-metadata.json format
+    sidecar = pathlib.Path(f"{filepath}.supplemental-metadata.json")
+    if sidecar.is_file():
+        return sidecar
+
     # if here, no sidecar found, check for Google Takeout formats
     # Google Takeout may append -edited to the file name but not the sidecar
     # If there is a duplicate file name, Google Takeout will append a number to the file name
@@ -164,8 +168,18 @@ def get_sidecar_for_file(filepath: str | pathlib.Path) -> pathlib.Path | None:
     # strip off (1) suffix for Google takeout naming scheme
     if match := re.match(r"(.*)(\(\d+\))$", stem):
         stem = match.groups()[0]
+        number_suffix = match.groups()[1]
+        # check for img_1234.jpg(1).json format
         new_filepath = pathlib.Path(
-            str(filepath.with_stem(stem)) + match.groups()[1] + ".json"
+            str(filepath.with_stem(stem)) + number_suffix + ".json"
+        )
+        if new_filepath.is_file():
+            return new_filepath
+        # check for img_1234.jpg(1).supplemental-metadata.json format
+        new_filepath = pathlib.Path(
+            str(filepath.with_stem(stem))
+            + number_suffix
+            + ".supplemental-metadata.json"
         )
         if new_filepath.is_file():
             return new_filepath
@@ -399,6 +413,7 @@ def metadata_from_metadata_dict(metadata: dict) -> MetaData:
         tz_offset_sec=tz_offset,
         height=height,
         width=width,
+        tzname=None,  # the sidecar doesn't store the timezone name
     )
 
 
@@ -537,4 +552,5 @@ def metadata_from_photoinfo(photoinfo: PhotoInfoProtocol) -> MetaData:
         tz_offset_sec=tz_offset,
         height=photoinfo.height,
         width=photoinfo.width,
+        tzname=photoinfo.tzname,
     )
