@@ -30,6 +30,7 @@ from .touch_files import touch_files
 from .unicode import normalize_fs_path
 from .uti import get_preferred_uti_extension
 from .utils import (
+    extract_increment_count_from_filename,
     increment_filename,
     increment_filename_with_count,
     isdir_cache,
@@ -286,6 +287,19 @@ class PhotoExporter:
         ):
             options.stat_cache.register_virtual_file(dest)
 
+        # claim_only: resolve the filename and register it without exporting;
+        # used when --skip-original-if-edited skips the original so the
+        # filename is still reserved for collision detection.
+        # Only registers in the export DB (not stat_cache) so that the same
+        # photo's edited version can still use this path via UUID matching
+        # in _get_dest_path, while other photos are blocked by the DB claim.
+        if options.claim_only:
+            all_results = ExportResults()
+            if options.export_db is not None:
+                options.export_db.create_or_get_file_record(str(dest), self.photo.uuid)
+            all_results.uuids[str(dest)] = self.photo.uuid
+            return all_results
+
         staged_files = self._stage_photos_for_export(options, dest=dest)
         src = staged_files.edited if options.edited else staged_files.original
 
@@ -556,7 +570,32 @@ class PhotoExporter:
         if options.increment and not any(
             [options.update, options.force_update, options.overwrite]
         ):
-            return pathlib.Path(increment_filename(dest, stat_cache=stat_cache))
+            original_dest = dest
+            dest = pathlib.Path(increment_filename(dest, stat_cache=stat_cache))
+            # Also check the export DB for names claimed by other UUIDs
+            # (e.g. from claim_only when --skip-original-if-edited is used).
+            # increment_filename only checks the filesystem; the DB check
+            # ensures we don't reuse a name reserved by a different photo.
+            if options.export_db:
+                export_db = options.export_db
+                # Only extract count from the incremented name if it was
+                # actually changed; otherwise a filename that naturally
+                # contains e.g. "(1)" would cause us to skip counts.
+                count = (
+                    extract_increment_count_from_filename(dest)
+                    if dest != original_dest
+                    else 0
+                )
+                while True:
+                    claimed_uuid = export_db.get_uuid_for_file(dest)
+                    if claimed_uuid is None or claimed_uuid == self.photo.uuid:
+                        break
+                    count += 1
+                    dest, count = increment_filename_with_count(
+                        original_dest, count, stat_cache=stat_cache
+                    )
+                    dest = pathlib.Path(dest)
+            return dest
 
         # if update and file exists, need to check to see if it's the right file by checking export db
         if options.update or options.force_update:
@@ -590,14 +629,15 @@ class PhotoExporter:
                     )
                 return pathlib.Path(candidate)
             else:
+                original_dest = dest
                 count = 0
                 dest, count = increment_filename_with_count(
-                    dest, count, stat_cache=stat_cache
+                    original_dest, count, stat_cache=stat_cache
                 )
-                count += 1
                 while export_db.get_uuid_for_file(dest) is not None:
+                    count += 1
                     dest, count = increment_filename_with_count(
-                        dest, count, stat_cache=stat_cache
+                        original_dest, count, stat_cache=stat_cache
                     )
                 return pathlib.Path(dest)
 
